==> open5gs_2.7.0.27.5d264.202312282026.tar.xz: BUILD/docs/_docs/hardware/01-genodebs.md <==
---
title: eNodeBs / gNodeBs tested on Open5GS
head_inline: "<style> .blue { color: blue; } .bold { font-weight: bold; } </style>"
---

This page lists Radio hardware that has been tested by members of the Open5GS community,

If you have tested radio hardware from a vendor not listed with Open5GS, please add it to this page [by creating a PR on GitHub.](https://github.com/open5gs/open5gs)

### Commercial 5G
---
 * Airfill S5G AFBU-SL14CN (DU + CU) + AFRU-352-I Indoor Radio (n77 and n78)
 * Airspan 5G OpenRange vCU + Airspan 5G OpenRange vDU + Airspan 5G OpenRANGE06 AirVelocity 2700 RU
 * Airspan AirSpeed 2900
 * Airspan AirStrand 2200
 * ASKEY SCE2200 5G SUB-6 SMALL CELL
 * BTI Wireless nCELL-F2240 5G NR Femtocell (n78)
 * CableFree Small Cell Outdoor radios (5G n77, n78 and other bands)
 * CableFree Small Cell Indoor radios (5G n77, n78 and other bands)
 * CableFree Macro (BBU+RRH) radios (4G and 5G, various bands)
 * Ericsson Baseband 6630 (21.Q3 Software) + Radio 2217, Radio 2219 (4G and 5G, various bands)
 * Ericsson StreetMacro 6701 (21.Q3 Software) (5G mmWave, n261) (Baseband 6318 and AIR 1281 packaged together)
 * Huawei BTS5900
 * LIONS RANathon O-CU and O-DU + RANathon RS8601 Indoor O-RU + RANathon XG8600 Fronthaul Gateway
 * NOKIA AEQE (SW: 5G20A)
 * NOKIA AEQD (SW: 5G20A)
 * NOKIA AEQP (SW: 5G21A)

### Commercial 4G
---

 * Accelleran E1010 (LTE TDD B42)
 * AirHarmony 4000
 * AirHarmony 4200
 * AirHarmony 4400
 * Airspan AirSpeed 1030
 * Airspan AirHarmony 1000
 * Baicells Neutrino
 * Baicells Nova 243
 * Baicells Nova 246
 * Baicells Nova 249
 * Baicells Nova 436Q
 * Baicells Nova 227 (EBS & CBRS)
 * Baicells Nova 233
 * Ericsson Baseband 6630 (21Q1 Software)
 * Ericsson RBS 6402 (18.Q1 software, B2 B25 B4 B7 B252 B255)
 * Ericsson RBS 6601 + DUL 20 01 + RUS 01 B8 
 * Gemtek WLTGFC-101 (S/W version 2.1.1746.1116)
 * Huawei BTS3900 (S/W version V100R011C10SPC230)
 * Huawei BBU5900 with RRU5304W Band 7 FDD 2600Mhz 40W Version V100R016C10
 * Klas VoyagerCell Duo 4GAP1000/4GAP1000X
 * Nokia FW2PC BC28 Flexi Zone G2 Outdoor Micro FDD LTE 700 MHz High Power
 * Nokia FWH1 B38 Flexi Zone Outdoor Micro TD LTE 2600 MHz
 * Nokia FRGY Flexi BTS BBU with Nokia FRCG RRU Band 5 850Mhz FDD 40W. Version 16.1A to 19.0
 * Nokia FW2FA Flexi Zone Mini-Macro Outdoor BTS, 2x20w Band 39
 * Nokia FWGR Flexi Zone Mini-Macro Outdoor BTS, 2x20w Band 1
 * Ruckus Q710 and Q910

### 4G/5G Software Stacks + SDRs
---

 * [Amarisoft](https://www.amarisoft.com/) + LimeSDR, USRP, Amarisoft PCI Express Card
 * Open Air Interface 5G ([NR_SA_F1AP_5GRECORDS branch](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/NR_SA_F1AP_5GRECORDS)) + USRP B210
 * [srsLTE / srsENB](https://github.com/srsLTE/srsLTE) + LimeSDR, USRP, BladeRF x40 (BladeRF Not stable)

### Misc Radio Hardware
---
 * [OpenAirInterface v1.0.3](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/v1.0.3) 4G RAN Simulator
 * [OsmoBTS](https://osmocom.org/projects/osmobts/wiki) controlled ip.access NanoBTS (Used for CSFB with Osmocom)
 * [UERANSIM](https://github.com/aligungr/UERANSIM) 5G RAN Simulator

==> open5gs_2.7.6.4742.d787.202508112026.tar.xz: BUILD/docs/_docs/hardware/01-genodebs.md <==
---
title: eNodeBs / gNodeBs tested on Open5GS
head_inline: "<style> .blue { color: blue; } .bold { font-weight: bold; } </style>"
---

This page lists Radio hardware that has been tested by members of the Open5GS community,

If you have tested radio hardware from a vendor not listed with Open5GS, please add it to this page [by creating a PR on GitHub.](https://github.com/open5gs/open5gs)

### Commercial 5G
---
 * Airfill S5G AFBU-SL14CN (DU + CU) + AFRU-352-I Indoor Radio (n77 and n78)
 * Airspan 5G OpenRange vCU + Airspan 5G OpenRange vDU + Airspan 5G OpenRANGE06 AirVelocity 2700 RU
 * Airspan AirSpeed 2900
 * Airspan AirStrand 2200
 * ASKEY SCE2200 5G SUB-6 SMALL CELL
 * BTI Wireless nCELL-F2240 5G NR Femtocell (n78)
 * CableFree Small Cell Outdoor radios (5G n77, n78 and other bands)
 * CableFree Small Cell Indoor radios (5G n77, n78 and other bands)
 * CableFree Macro (BBU+RRH) radios (4G and 5G, various bands)
 * Ericsson Baseband 6630 (21.Q3 Software) + Radio 2217, Radio 2219 (4G and 5G, various bands)
 * Ericsson StreetMacro 6701 (21.Q3 Software) (5G mmWave, n261) (Baseband 6318 and AIR 1281 packaged together)
 * Huawei BTS5900
 * LIONS RANathon O-CU and O-DU + RANathon RS8601 Indoor O-RU + RANathon XG8600 Fronthaul Gateway
 * NOKIA AEQE (SW: 5G20A)
 * NOKIA AEQD (SW: 5G20A)
 * NOKIA AEQP (SW: 5G21A)

### Commercial 4G
---

 * Accelleran E1010 (LTE TDD B42)
 * AirHarmony 4000
 * AirHarmony 4200
 * AirHarmony 4400
 * Airspan AirSpeed 1030
 * Airspan AirHarmony 1000
 * Baicells Neutrino
 * Baicells Nova 243
 * Baicells Nova 246
 * Baicells Nova 249
 * Baicells Nova 436Q
 * Baicells Nova 227 (EBS & CBRS)
 * Baicells Nova 233
 * Baicells Nova 430i (band 48/CBRS, SW version BaiBLQ_3.0.12)
 * Ericsson Baseband 6630 (21Q1 Software)
 * Ericsson RBS 6402 (18.Q1 software, B2 B25 B4 B7 B252 B255)
 * Ericsson RBS 6601 + DUL 20 01 + RUS 01 B8 
 * Gemtek WLTGFC-101 (S/W version 2.1.1746.1116)
 * Gemtek WLTGFC-105 (band 3, SW version 2.1.2277.1720-wltgfc105-gemtek-fdd)
 * Huawei BTS3900 (S/W version V100R011C10SPC230)
 * Huawei BBU5900 with RRU5304W Band 7 FDD 2600Mhz 40W Version V100R016C10
 * Klas VoyagerCell Duo 4GAP1000/4GAP1000X
 * Nokia FW2PC BC28 Flexi Zone G2 Outdoor Micro FDD LTE 700 MHz High Power
 * Nokia FWH1 B38 Flexi Zone Outdoor Micro TD LTE 2600 MHz
 * Nokia FRGY Flexi BTS BBU with Nokia FRCG RRU Band 5 850Mhz FDD 40W. Version 16.1A to 19.0
 * Nokia FW2FA Flexi Zone Mini-Macro Outdoor BTS, 2x20w Band 39
 * Nokia FWGR Flexi Zone Mini-Macro Outdoor BTS, 2x20w Band 1
 * Nokia FWHG Flexi Zone Indoor Pico BTS, 2x250 mW Band 7
 * Nokia FW2HHD Flexi Zone Multiband Indoor Pico BTS, Band 38/41(S/W TLS18SP_ENB)
 * Ruckus Q710 and Q910
 * Sercomm SCE4255W "Englewood" (band 48/CBRS, SW version DG3934v3@2308041842)

### 4G/5G Software Stacks + SDRs
---

 * [Amarisoft](https://www.amarisoft.com/) + LimeSDR, USRP, Amarisoft PCI Express Card
 * Open Air Interface 5G ([NR_SA_F1AP_5GRECORDS branch](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/NR_SA_F1AP_5GRECORDS)) + USRP B210
 * [srsLTE / srsENB](https://github.com/srsLTE/srsLTE) + LimeSDR, USRP, BladeRF x40 (BladeRF Not stable)

### Misc Radio Hardware
---
 * [OpenAirInterface v1.0.3](https://gitlab.eurecom.fr/oai/openairinterface5g/-/tree/v1.0.3) 4G RAN Simulator
 * [OsmoBTS](https://osmocom.org/projects/osmobts/wiki) controlled ip.access NanoBTS (Used for CSFB with Osmocom)
 * [UERANSIM](https://github.com/aligungr/UERANSIM) 5G RAN Simulator
